/*
 * frequencies.c: wirbelscan - A plugin for the Video Disk Recorder
 *
 * See the README file for copyright information and how to reach the author.
 *
 * $Id$
 */


/* see VIDEO::FREQUENCIES or other ressources from net
   there are a lot of equivalent files around
 */

#include <stdlib.h>
#include <linux/types.h>

#include "frequencies.h"
#include <linux/videodev2.h>



/* US NTSC broadcast */

#define FREQ_NTSC_BCAST \
    { "NTSC 2",       55250 }, \
    { "NTSC 3",       61250 }, \
    { "NTSC 4",       67250 }, \
    { "NTSC 5",       77250 }, \
    { "NTSC 6",       83250 }, \
    { "NTSC 7",      175250 }, \
    { "NTSC 8",      181250 }, \
    { "NTSC 9",      187250 }, \
    { "NTSC 10",     193250 }, \
    { "NTSC 11",     199250 }, \
    { "NTSC 12",     205250 }, \
    { "NTSC 13",     211250 }, \
    { "NTSC 14",     471250 }, \
    { "NTSC 15",     477250 }, \
    { "NTSC 16",     483250 }, \
    { "NTSC 17",     489250 }, \
    { "NTSC 18",     495250 }, \
    { "NTSC 19",     501250 }, \
    { "NTSC 20",     507250 }, \
    { "NTSC 21",     513250 }, \
    { "NTSC 22",     519250 }, \
    { "NTSC 23",     525250 }, \
    { "NTSC 24",     531250 }, \
    { "NTSC 25",     537250 }, \
    { "NTSC 26",     543250 }, \
    { "NTSC 27",     549250 }, \
    { "NTSC 28",     555250 }, \
    { "NTSC 29",     561250 }, \
    { "NTSC 30",     567250 }, \
    { "NTSC 31",     573250 }, \
    { "NTSC 32",     579250 }, \
    { "NTSC 33",     585250 }, \
    { "NTSC 34",     591250 }, \
    { "NTSC 35",     597250 }, \
    { "NTSC 36",     603250 }, \
    { "NTSC 37",     609250 }, \
    { "NTSC 38",     615250 }, \
    { "NTSC 39",     621250 }, \
    { "NTSC 40",     627250 }, \
    { "NTSC 41",     633250 }, \
    { "NTSC 42",     639250 }, \
    { "NTSC 43",     645250 }, \
    { "NTSC 44",     651250 }, \
    { "NTSC 45",     657250 }, \
    { "NTSC 46",     663250 }, \
    { "NTSC 47",     669250 }, \
    { "NTSC 48",     675250 }, \
    { "NTSC 49",     681250 }, \
    { "NTSC 50",     687250 }, \
    { "NTSC 51",     693250 }, \
    { "NTSC 52",     699250 }, \
    { "NTSC 53",     705250 }, \
    { "NTSC 54",     711250 }, \
    { "NTSC 55",     717250 }, \
    { "NTSC 56",     723250 }, \
    { "NTSC 57",     729250 }, \
    { "NTSC 58",     735250 }, \
    { "NTSC 59",     741250 }, \
    { "NTSC 60",     747250 }, \
    { "NTSC 61",     753250 }, \
    { "NTSC 62",     759250 }, \
    { "NTSC 63",     765250 }, \
    { "NTSC 64",     771250 }, \
    { "NTSC 65",     777250 }, \
    { "NTSC 66",     783250 }, \
    { "NTSC 67",     789250 }, \
    { "NTSC 68",     795250 }, \
    { "NTSC 69",     801250 }, \
    { "NTSC 70",     807250 }, \
    { "NTSC 71",     813250 }, \
    { "NTSC 72",     819250 }, \
    { "NTSC 73",     825250 }, \
    { "NTSC 74",     831250 }, \
    { "NTSC 75",     837250 }, \
    { "NTSC 76",     843250 }, \
    { "NTSC 77",     849250 }, \
    { "NTSC 78",     855250 }, \
    { "NTSC 79",     861250 }, \
    { "NTSC 80",     867250 }, \
    { "NTSC 81",     873250 }, \
    { "NTSC 82",     879250 }, \
    { "NTSC 83",     885250 }

/* US NTSC cable */

#define FREQ_NTSC_CABLE \
    { "NTSC 1",       73250 }, \
    { "NTSC 2",       55250 }, \
    { "NTSC 3",       61250 }, \
    { "NTSC 4",       67250 }, \
    { "NTSC 5",       77250 }, \
    { "NTSC 6",       83250 }, \
    { "NTSC 7",      175250 }, \
    { "NTSC 8",      181250 }, \
    { "NTSC 9",      187250 }, \
    { "NTSC 10",     193250 }, \
    { "NTSC 11",     199250 }, \
    { "NTSC 12",     205250 }, \
    { "NTSC 13",     211250 }, \
    { "NTSC 14",     121250 }, \
    { "NTSC 15",     127250 }, \
    { "NTSC 16",     133250 }, \
    { "NTSC 17",     139250 }, \
    { "NTSC 18",     145250 }, \
    { "NTSC 19",     151250 }, \
    { "NTSC 20",     157250 }, \
    { "NTSC 21",     163250 }, \
    { "NTSC 22",     169250 }, \
    { "NTSC 23",     217250 }, \
    { "NTSC 24",     223250 }, \
    { "NTSC 25",     229250 }, \
    { "NTSC 26",     235250 }, \
    { "NTSC 27",     241250 }, \
    { "NTSC 28",     247250 }, \
    { "NTSC 29",     253250 }, \
    { "NTSC 30",     259250 }, \
    { "NTSC 31",     265250 }, \
    { "NTSC 32",     271250 }, \
    { "NTSC 33",     277250 }, \
    { "NTSC 34",     283250 }, \
    { "NTSC 35",     289250 }, \
    { "NTSC 36",     295250 }, \
    { "NTSC 37",     301250 }, \
    { "NTSC 38",     307250 }, \
    { "NTSC 39",     313250 }, \
    { "NTSC 40",     319250 }, \
    { "NTSC 41",     325250 }, \
    { "NTSC 42",     331250 }, \
    { "NTSC 43",     337250 }, \
    { "NTSC 44",     343250 }, \
    { "NTSC 45",     349250 }, \
    { "NTSC 46",     355250 }, \
    { "NTSC 47",     361250 }, \
    { "NTSC 48",     367250 }, \
    { "NTSC 49",     373250 }, \
    { "NTSC 50",     379250 }, \
    { "NTSC 51",     385250 }, \
    { "NTSC 52",     391250 }, \
    { "NTSC 53",     397250 }, \
    { "NTSC 54",     403250 }, \
    { "NTSC 55",     409250 }, \
    { "NTSC 56",     415250 }, \
    { "NTSC 57",     421250 }, \
    { "NTSC 58",     427250 }, \
    { "NTSC 59",     433250 }, \
    { "NTSC 60",     439250 }, \
    { "NTSC 61",     445250 }, \
    { "NTSC 62",     451250 }, \
    { "NTSC 63",     457250 }, \
    { "NTSC 64",     463250 }, \
    { "NTSC 65",     469250 }, \
    { "NTSC 66",     475250 }, \
    { "NTSC 67",     481250 }, \
    { "NTSC 68",     487250 }, \
    { "NTSC 69",     493250 }, \
    { "NTSC 70",     499250 }, \
    { "NTSC 71",     505250 }, \
    { "NTSC 72",     511250 }, \
    { "NTSC 73",     517250 }, \
    { "NTSC 74",     523250 }, \
    { "NTSC 75",     529250 }, \
    { "NTSC 76",     535250 }, \
    { "NTSC 77",     541250 }, \
    { "NTSC 78",     547250 }, \
    { "NTSC 79",     553250 }, \
    { "NTSC 80",     559250 }, \
    { "NTSC 81",     565250 }, \
    { "NTSC 82",     571250 }, \
    { "NTSC 83",     577250 }, \
    { "NTSC 84",     583250 }, \
    { "NTSC 85",     589250 }, \
    { "NTSC 86",     595250 }, \
    { "NTSC 87",     601250 }, \
    { "NTSC 88",     607250 }, \
    { "NTSC 89",     613250 }, \
    { "NTSC 90",     619250 }, \
    { "NTSC 91",     625250 }, \
    { "NTSC 92",     631250 }, \
    { "NTSC 93",     637250 }, \
    { "NTSC 94",     643250 }, \
    { "NTSC 95",      91250 }, \
    { "NTSC 96",      97250 }, \
    { "NTSC 97",     103250 }, \
    { "NTSC 98",     109250 }, \
    { "NTSC 99",     115250 }, \
    { "NTSC 100",    649250 }, \
    { "NTSC 101",    655250 }, \
    { "NTSC 102",    661250 }, \
    { "NTSC 103",    667250 }, \
    { "NTSC 104",    673250 }, \
    { "NTSC 105",    679250 }, \
    { "NTSC 106",    685250 }, \
    { "NTSC 107",    691250 }, \
    { "NTSC 108",    697250 }, \
    { "NTSC 109",    703250 }, \
    { "NTSC 110",    709250 }, \
    { "NTSC 111",    715250 }, \
    { "NTSC 112",    721250 }, \
    { "NTSC 113",     27250 }, \
    { "NTSC 114",    733250 }, \
    { "NTSC 115",    739250 }, \
    { "NTSC 116",    745250 }, \
    { "NTSC 117",    751250 }, \
    { "NTSC 118",    757250 }, \
    { "NTSC 119",    763250 }, \
    { "NTSC 120",    769250 }, \
    { "NTSC 121",    775250 }, \
    { "NTSC 122",    781250 }, \
    { "NTSC 123",    787250 }, \
    { "NTSC 124",    793250 }, \
    { "NTSC 125",    799250 }, \
    { "NTSC T7",       8250 }, \
    { "NTSC T8",      14250 }, \
    { "NTSC T9",      20250 }, \
    { "NTSC T10",     26250 }, \
    { "NTSC T11",     32250 }, \
    { "NTSC T12",     38250 }, \
    { "NTSC T13",     44250 }, \
    { "NTSC T14",     50250 }

    
    
/* US NTSC HRC */

#define FREQ_NTSC_HRC \
    { "NTSC HRC 1",       72000 }, \
    { "NTSC HRC 2",       54000 }, \
    { "NTSC HRC 3",       60000 }, \
    { "NTSC HRC 4",       66000 }, \
    { "NTSC HRC 5",       78000 }, \
    { "NTSC HRC 6",       84000 }, \
    { "NTSC HRC 7",      174000 }, \
    { "NTSC HRC 8",      180000 }, \
    { "NTSC HRC 9",      186000 }, \
    { "NTSC HRC 10",     192000 }, \
    { "NTSC HRC 11",     198000 }, \
    { "NTSC HRC 12",     204000 }, \
    { "NTSC HRC 13",     210000 }, \
    { "NTSC HRC 14",     120000 }, \
    { "NTSC HRC 15",     126000 }, \
    { "NTSC HRC 16",     132000 }, \
    { "NTSC HRC 17",     138000 }, \
    { "NTSC HRC 18",     144000 }, \
    { "NTSC HRC 19",     150000 }, \
    { "NTSC HRC 20",     156000 }, \
    { "NTSC HRC 21",     162000 }, \
    { "NTSC HRC 22",     168000 }, \
    { "NTSC HRC 23",     216000 }, \
    { "NTSC HRC 24",     222000 }, \
    { "NTSC HRC 25",     228000 }, \
    { "NTSC HRC 26",     234000 }, \
    { "NTSC HRC 27",     240000 }, \
    { "NTSC HRC 28",     246000 }, \
    { "NTSC HRC 29",     252000 }, \
    { "NTSC HRC 30",     258000 }, \
    { "NTSC HRC 31",     264000 }, \
    { "NTSC HRC 32",     270000 }, \
    { "NTSC HRC 33",     276000 }, \
    { "NTSC HRC 34",     282000 }, \
    { "NTSC HRC 35",     288000 }, \
    { "NTSC HRC 36",     294000 }, \
    { "NTSC HRC 37",     300000 }, \
    { "NTSC HRC 38",     306000 }, \
    { "NTSC HRC 39",     312000 }, \
    { "NTSC HRC 40",     318000 }, \
    { "NTSC HRC 41",     324000 }, \
    { "NTSC HRC 42",     330000 }, \
    { "NTSC HRC 43",     336000 }, \
    { "NTSC HRC 44",     342000 }, \
    { "NTSC HRC 45",     348000 }, \
    { "NTSC HRC 46",     354000 }, \
    { "NTSC HRC 47",     360000 }, \
    { "NTSC HRC 48",     366000 }, \
    { "NTSC HRC 49",     372000 }, \
    { "NTSC HRC 50",     378000 }, \
    { "NTSC HRC 51",     384000 }, \
    { "NTSC HRC 52",     390000 }, \
    { "NTSC HRC 53",     396000 }, \
    { "NTSC HRC 54",     402000 }, \
    { "NTSC HRC 55",     408000 }, \
    { "NTSC HRC 56",     414000 }, \
    { "NTSC HRC 57",     420000 }, \
    { "NTSC HRC 58",     426000 }, \
    { "NTSC HRC 59",     432000 }, \
    { "NTSC HRC 60",     438000 }, \
    { "NTSC HRC 61",     444000 }, \
    { "NTSC HRC 62",     450000 }, \
    { "NTSC HRC 63",     456000 }, \
    { "NTSC HRC 64",     462000 }, \
    { "NTSC HRC 65",     468000 }, \
    { "NTSC HRC 66",     474000 }, \
    { "NTSC HRC 67",     480000 }, \
    { "NTSC HRC 68",     486000 }, \
    { "NTSC HRC 69",     492000 }, \
    { "NTSC HRC 70",     498000 }, \
    { "NTSC HRC 71",     504000 }, \
    { "NTSC HRC 72",     510000 }, \
    { "NTSC HRC 73",     516000 }, \
    { "NTSC HRC 74",     522000 }, \
    { "NTSC HRC 75",     528000 }, \
    { "NTSC HRC 76",     534000 }, \
    { "NTSC HRC 77",     540000 }, \
    { "NTSC HRC 78",     546000 }, \
    { "NTSC HRC 79",     552000 }, \
    { "NTSC HRC 80",     558000 }, \
    { "NTSC HRC 81",     564000 }, \
    { "NTSC HRC 82",     570000 }, \
    { "NTSC HRC 83",     576000 }, \
    { "NTSC HRC 84",     582000 }, \
    { "NTSC HRC 85",     588000 }, \
    { "NTSC HRC 86",     594000 }, \
    { "NTSC HRC 87",     600000 }, \
    { "NTSC HRC 88",     606000 }, \
    { "NTSC HRC 89",     612000 }, \
    { "NTSC HRC 90",     618000 }, \
    { "NTSC HRC 91",     624000 }, \
    { "NTSC HRC 92",     630000 }, \
    { "NTSC HRC 93",     636000 }, \
    { "NTSC HRC 94",     642000 }, \
    { "NTSC HRC 95",      90000 }, \
    { "NTSC HRC 96",      96000 }, \
    { "NTSC HRC 97",     102000 }, \
    { "NTSC HRC 98",     108000 }, \
    { "NTSC HRC 99",     114000 }, \
    { "NTSC HRC 100",    648000 }, \
    { "NTSC HRC 101",    654000 }, \
    { "NTSC HRC 102",    660000 }, \
    { "NTSC HRC 103",    666000 }, \
    { "NTSC HRC 104",    672000 }, \
    { "NTSC HRC 105",    678000 }, \
    { "NTSC HRC 106",    684000 }, \
    { "NTSC HRC 107",    690000 }, \
    { "NTSC HRC 108",    696000 }, \
    { "NTSC HRC 109",    702000 }, \
    { "NTSC HRC 110",    708000 }, \
    { "NTSC HRC 111",    714000 }, \
    { "NTSC HRC 112",    720000 }, \
    { "NTSC HRC 113",    726000 }, \
    { "NTSC HRC 114",    732000 }, \
    { "NTSC HRC 115",    738000 }, \
    { "NTSC HRC 116",    744000 }, \
    { "NTSC HRC 117",    750000 }, \
    { "NTSC HRC 118",    756000 }, \
    { "NTSC HRC 119",    762000 }, \
    { "NTSC HRC 120",    768000 }, \
    { "NTSC HRC 121",    774000 }, \
    { "NTSC HRC 122",    780000 }, \
    { "NTSC HRC 123",    786000 }, \
    { "NTSC HRC 124",    792000 }, \
    { "NTSC HRC 125",    798000 }, \
    { "NTSC HRC T7",       7000 }, \
    { "NTSC HRC T8",      13000 }, \
    { "NTSC HRC T9",      19000 }, \
    { "NTSC HRC T10",     25000 }, \
    { "NTSC HRC T11",     31000 }, \
    { "NTSC HRC T12",     37000 }, \
    { "NTSC HRC T13",     43000 }, \
    { "NTSC HRC T14",     49000 }

/* US NTSC IRC */

#define FREQ_NTSC_IRC \
    { "NTSC IRC 1",       73250 }, \
    { "NTSC IRC 2",       55250 }, \
    { "NTSC IRC 3",       61250 }, \
    { "NTSC IRC 4",       67250 }, \
    { "NTSC IRC 5",       79250 }, \
    { "NTSC IRC 6",       85250 }, \
    { "NTSC IRC 7",      175250 }, \
    { "NTSC IRC 8",      181250 }, \
    { "NTSC IRC 9",      187250 }, \
    { "NTSC IRC 10",     193250 }, \
    { "NTSC IRC 11",     199250 }, \
    { "NTSC IRC 12",     205250 }, \
    { "NTSC IRC 13",     211250 }, \
    { "NTSC IRC 14",     121150 }, \
    { "NTSC IRC 15",     127150 }, \
    { "NTSC IRC 16",     133150 }, \
    { "NTSC IRC 17",     139150 }, \
    { "NTSC IRC 18",     145150 }, \
    { "NTSC IRC 19",     151150 }, \
    { "NTSC IRC 20",     157150 }, \
    { "NTSC IRC 21",     163150 }, \
    { "NTSC IRC 22",     169150 }, \
    { "NTSC IRC 23",     217250 }, \
    { "NTSC IRC 24",     223250 }, \
    { "NTSC IRC 25",     229250 }, \
    { "NTSC IRC 26",     235250 }, \
    { "NTSC IRC 27",     241250 }, \
    { "NTSC IRC 28",     247250 }, \
    { "NTSC IRC 29",     253250 }, \
    { "NTSC IRC 30",     259250 }, \
    { "NTSC IRC 31",     265250 }, \
    { "NTSC IRC 32",     271250 }, \
    { "NTSC IRC 33",     277250 }, \
    { "NTSC IRC 34",     283250 }, \
    { "NTSC IRC 35",     289250 }, \
    { "NTSC IRC 36",     295250 }, \
    { "NTSC IRC 37",     301250 }, \
    { "NTSC IRC 38",     307250 }, \
    { "NTSC IRC 39",     313250 }, \
    { "NTSC IRC 40",     319250 }, \
    { "NTSC IRC 41",     325250 }, \
    { "NTSC IRC 42",     331250 }, \
    { "NTSC IRC 43",     337250 }, \
    { "NTSC IRC 44",     343250 }, \
    { "NTSC IRC 45",     349250 }, \
    { "NTSC IRC 46",     355250 }, \
    { "NTSC IRC 47",     361250 }, \
    { "NTSC IRC 48",     367250 }, \
    { "NTSC IRC 49",     373250 }, \
    { "NTSC IRC 50",     379250 }, \
    { "NTSC IRC 51",     385250 }, \
    { "NTSC IRC 52",     391250 }, \
    { "NTSC IRC 53",     397250 }, \
    { "NTSC IRC 54",     403250 }, \
    { "NTSC IRC 55",     409250 }, \
    { "NTSC IRC 56",     415250 }, \
    { "NTSC IRC 57",     421250 }, \
    { "NTSC IRC 58",     427250 }, \
    { "NTSC IRC 59",     433250 }, \
    { "NTSC IRC 60",     439250 }, \
    { "NTSC IRC 61",     445250 }, \
    { "NTSC IRC 62",     451250 }, \
    { "NTSC IRC 63",     457250 }, \
    { "NTSC IRC 64",     463250 }, \
    { "NTSC IRC 65",     469250 }, \
    { "NTSC IRC 66",     475250 }, \
    { "NTSC IRC 67",     481250 }, \
    { "NTSC IRC 68",     487250 }, \
    { "NTSC IRC 69",     493250 }, \
    { "NTSC IRC 70",     499250 }, \
    { "NTSC IRC 71",     505250 }, \
    { "NTSC IRC 72",     511250 }, \
    { "NTSC IRC 73",     517250 }, \
    { "NTSC IRC 74",     523250 }, \
    { "NTSC IRC 75",     529250 }, \
    { "NTSC IRC 76",     535250 }, \
    { "NTSC IRC 77",     541250 }, \
    { "NTSC IRC 78",     547250 }, \
    { "NTSC IRC 79",     553250 }, \
    { "NTSC IRC 80",     559250 }, \
    { "NTSC IRC 81",     565250 }, \
    { "NTSC IRC 82",     571250 }, \
    { "NTSC IRC 83",     577250 }, \
    { "NTSC IRC 84",     583250 }, \
    { "NTSC IRC 85",     589250 }, \
    { "NTSC IRC 86",     595250 }, \
    { "NTSC IRC 87",     601250 }, \
    { "NTSC IRC 88",     607250 }, \
    { "NTSC IRC 89",     613250 }, \
    { "NTSC IRC 90",     619250 }, \
    { "NTSC IRC 91",     625250 }, \
    { "NTSC IRC 92",     631250 }, \
    { "NTSC IRC 93",     637250 }, \
    { "NTSC IRC 94",     643250 }, \
    { "NTSC IRC 95",      91250 }, \
    { "NTSC IRC 96",      97250 }, \
    { "NTSC IRC 97",     103250 }, \
    { "NTSC IRC 98",     109250 }, \
    { "NTSC IRC 99",     115250 }, \
    { "NTSC IRC 100",    649250 }, \
    { "NTSC IRC 101",    655250 }, \
    { "NTSC IRC 102",    661250 }, \
    { "NTSC IRC 103",    667250 }, \
    { "NTSC IRC 104",    673250 }, \
    { "NTSC IRC 105",    679250 }, \
    { "NTSC IRC 106",    685250 }, \
    { "NTSC IRC 107",    691250 }, \
    { "NTSC IRC 108",    697250 }, \
    { "NTSC IRC 109",    703250 }, \
    { "NTSC IRC 110",    709250 }, \
    { "NTSC IRC 111",    715250 }, \
    { "NTSC IRC 112",    721250 }, \
    { "NTSC IRC 113",    727250 }, \
    { "NTSC IRC 114",    733250 }, \
    { "NTSC IRC 115",    739250 }, \
    { "NTSC IRC 116",    745250 }, \
    { "NTSC IRC 117",    751250 }, \
    { "NTSC IRC 118",    757250 }, \
    { "NTSC IRC 119",    763250 }, \
    { "NTSC IRC 120",    769250 }, \
    { "NTSC IRC 121",    775250 }, \
    { "NTSC IRC 122",    781250 }, \
    { "NTSC IRC 123",    787250 }, \
    { "NTSC IRC 124",    793250 }, \
    { "NTSC IRC 125",    799250 }, \
    { "NTSC IRC T7",       8250 }, \
    { "NTSC IRC T8",      14250 }, \
    { "NTSC IRC T9",      20250 }, \
    { "NTSC IRC T10",     26250 }, \
    { "NTSC IRC T11",     32250 }, \
    { "NTSC IRC T12",     38250 }, \
    { "NTSC IRC T13",     44250 }, \
    { "NTSC IRC T14",     50250 }


static struct cFreqlist ntsc[] = {
   FREQ_NTSC_BCAST,
   FREQ_NTSC_CABLE,
   FREQ_NTSC_HRC,
   FREQ_NTSC_IRC
};


/* JP NTSC broadcast */

#define FREQ_NTSC_BCAST_JP \
    { "NTSC JP 1",       91250 }, \
    { "NTSC JP 2",       97250 }, \
    { "NTSC JP 3",      103250 }, \
    { "NTSC JP 4",      171250 }, \
    { "NTSC JP 5",      177250 }, \
    { "NTSC JP 6",      183250 }, \
    { "NTSC JP 7",      189250 }, \
    { "NTSC JP 8",      193250 }, \
    { "NTSC JP 9",      199250 }, \
    { "NTSC JP 10",     205250 }, \
    { "NTSC JP 11",     211250 }, \
    { "NTSC JP 12",     217250 }, \
    { "NTSC JP 13",     471250 }, \
    { "NTSC JP 14",     477250 }, \
    { "NTSC JP 15",     483250 }, \
    { "NTSC JP 16",     489250 }, \
    { "NTSC JP 17",     495250 }, \
    { "NTSC JP 18",     501250 }, \
    { "NTSC JP 19",     507250 }, \
    { "NTSC JP 20",     513250 }, \
    { "NTSC JP 21",     519250 }, \
    { "NTSC JP 22",     525250 }, \
    { "NTSC JP 23",     531250 }, \
    { "NTSC JP 24",     537250 }, \
    { "NTSC JP 25",     543250 }, \
    { "NTSC JP 26",     549250 }, \
    { "NTSC JP 27",     555250 }, \
    { "NTSC JP 28",     561250 }, \
    { "NTSC JP 29",     567250 }, \
    { "NTSC JP 30",     573250 }, \
    { "NTSC JP 31",     579250 }, \
    { "NTSC JP 32",     585250 }, \
    { "NTSC JP 33",     591250 }, \
    { "NTSC JP 34",     597250 }, \
    { "NTSC JP 35",     603250 }, \
    { "NTSC JP 36",     609250 }, \
    { "NTSC JP 37",     615250 }, \
    { "NTSC JP 38",     621250 }, \
    { "NTSC JP 39",     627250 }, \
    { "NTSC JP 40",     633250 }, \
    { "NTSC JP 41",     639250 }, \
    { "NTSC JP 42",     645250 }, \
    { "NTSC JP 43",     651250 }, \
    { "NTSC JP 44",     657250 }, \
    { "NTSC JP 45",     663250 }, \
    { "NTSC JP 46",     669250 }, \
    { "NTSC JP 47",     675250 }, \
    { "NTSC JP 48",     681250 }, \
    { "NTSC JP 49",     687250 }, \
    { "NTSC JP 50",     693250 }, \
    { "NTSC JP 51",     699250 }, \
    { "NTSC JP 52",     705250 }, \
    { "NTSC JP 53",     711250 }, \
    { "NTSC JP 54",     717250 }, \
    { "NTSC JP 55",     723250 }, \
    { "NTSC JP 56",     729250 }, \
    { "NTSC JP 57",     735250 }, \
    { "NTSC JP 58",     741250 }, \
    { "NTSC JP 59",     747250 }, \
    { "NTSC JP 60",     753250 }, \
    { "NTSC JP 61",     759250 }, \
    { "NTSC JP 62",     765250 }
 
/* JP NTSC cable */
#define FREQ_NTSC_CABLE_JP \
    { "NTSC JP 13",     109250 }, \
    { "NTSC JP 14",     115250 }, \
    { "NTSC JP 15",     121250 }, \
    { "NTSC JP 16",     127250 }, \
    { "NTSC JP 17",     133250 }, \
    { "NTSC JP 18",     139250 }, \
    { "NTSC JP 19",     145250 }, \
    { "NTSC JP 20",     151250 }, \
    { "NTSC JP 21",     157250 }, \
    { "NTSC JP 22",     165250 }, \
    { "NTSC JP 23",     223250 }, \
    { "NTSC JP 24",     231250 }, \
    { "NTSC JP 25",     237250 }, \
    { "NTSC JP 26",     243250 }, \
    { "NTSC JP 27",     249250 }, \
    { "NTSC JP 28",     253250 }, \
    { "NTSC JP 29",     259250 }, \
    { "NTSC JP 30",     265250 }, \
    { "NTSC JP 31",     271250 }, \
    { "NTSC JP 32",     277250 }, \
    { "NTSC JP 33",     283250 }, \
    { "NTSC JP 34",     289250 }, \
    { "NTSC JP 35",     295250 }, \
    { "NTSC JP 36",     301250 }, \
    { "NTSC JP 37",     307250 }, \
    { "NTSC JP 38",     313250 }, \
    { "NTSC JP 39",     319250 }, \
    { "NTSC JP 40",     325250 }, \
    { "NTSC JP 41",     331250 }, \
    { "NTSC JP 42",     337250 }, \
    { "NTSC JP 43",     343250 }, \
    { "NTSC JP 44",     349250 }, \
    { "NTSC JP 45",     355250 }, \
    { "NTSC JP 46",     361250 }, \
    { "NTSC JP 47",     367250 }, \
    { "NTSC JP 48",     373250 }, \
    { "NTSC JP 49",     379250 }, \
    { "NTSC JP 50",     385250 }, \
    { "NTSC JP 51",     391250 }, \
    { "NTSC JP 52",     397250 }, \
    { "NTSC JP 53",     403250 }, \
    { "NTSC JP 54",     409250 }, \
    { "NTSC JP 55",     415250 }, \
    { "NTSC JP 56",     421250 }, \
    { "NTSC JP 57",     427250 }, \
    { "NTSC JP 58",     433250 }, \
    { "NTSC JP 59",     439250 }, \
    { "NTSC JP 60",     445250 }, \
    { "NTSC JP 61",     451250 }, \
    { "NTSC JP 62",     457250 }, \
    { "NTSC JP 63",     463250 }
     
static struct cFreqlist ntsc_japan[] = {
 FREQ_NTSC_BCAST_JP,
 FREQ_NTSC_CABLE_JP
};

   
/* PAL australia */
static struct cFreqlist pal_australia[] = {
    { "PAL 0",       46250 },
    { "PAL 1",       57250 },
    { "PAL 2",       64250 },
    { "PAL 3",       86250 },
    { "PAL 4",       95250 },
    { "PAL 5",      102250 },
    { "PAL 5A",     138250 },
    { "PAL 6",      175250 },
    { "PAL 7",      182250 },
    { "PAL 8",      189250 },
    { "PAL 9",      196250 },
    { "PAL 10",     209250 },
    { "PAL 11",     216250 },
    { "PAL 28",     527250 },
    { "PAL 29",     534250 },
    { "PAL 30",     541250 },
    { "PAL 31",     548250 },
    { "PAL 32",     555250 },
    { "PAL 33",     562250 },
    { "PAL 34",     569250 },
    { "PAL 35",     576250 },
    { "PAL 36",     591250 },
    { "PAL 39",     604250 },
    { "PAL 40",     611250 },
    { "PAL 41",     618250 },
    { "PAL 42",     625250 },
    { "PAL 43",     632250 },
    { "PAL 44",     639250 },
    { "PAL 45",     646250 },
    { "PAL 46",     653250 },
    { "PAL 47",     660250 },
    { "PAL 48",     667250 },
    { "PAL 49",     674250 },
    { "PAL 50",     681250 },
    { "PAL 51",     688250 },
    { "PAL 52",     695250 },
    { "PAL 53",     702250 },
    { "PAL 54",     709250 },
    { "PAL 55",     716250 },
    { "PAL 56",     723250 },
    { "PAL 57",     730250 },
    { "PAL 58",     737250 },
    { "PAL 59",     744250 },
    { "PAL 60",     751250 },
    { "PAL 61",     758250 },
    { "PAL 62",     765250 },
    { "PAL 63",     772250 },
    { "PAL 64",     779250 },
    { "PAL 65",     786250 },
    { "PAL 66",     793250 },
    { "PAL 67",     800250 },
    { "PAL 68",     807250 },
    { "PAL 69",     814250 },
};

static struct cFreqlist pal_australia_optus[] = {
    { "PAL 1",      138250 },
    { "PAL 2",      147250 },
    { "PAL 3",      154250 },
    { "PAL 4",      161250 },
    { "PAL 5",      168250 },
    { "PAL 6",      175250 },
    { "PAL 7",      182250 },
    { "PAL 8",      189250 },
    { "PAL 9",      196250 },
    { "PAL 10",     209250 },
    { "PAL 11",     216250 },
    { "PAL 12",     224250 },
    { "PAL 13",     231250 },
    { "PAL 14",     238250 },
    { "PAL 15",     245250 },
    { "PAL 16",     252250 },
    { "PAL 17",     259250 },
    { "PAL 18",     266250 },
    { "PAL 19",     273250 },
    { "PAL 20",     280250 },
    { "PAL 21",     287250 },
    { "PAL 22",     294250 },
    { "PAL 23",     303250 },
    { "PAL 24",     310250 },
    { "PAL 25",     317250 },
    { "PAL 26",     324250 },
    { "PAL 27",     338250 },
    { "PAL 28",     345250 },
    { "PAL 29",     352250 },
    { "PAL 30",     359250 },
    { "PAL 31",     366250 },
    { "PAL 32",     373250 },
    { "PAL 33",     380250 },
    { "PAL 34",     387250 },
    { "PAL 35",     394250 },
    { "PAL 36",     401250 },
    { "PAL 37",     408250 },
    { "PAL 38",     415250 },
    { "PAL 39",     422250 },
    { "PAL 40",     429250 },
    { "PAL 41",     436250 },
    { "PAL 42",     443250 },
    { "PAL 43",     450250 },
    { "PAL 44",     457250 },
    { "PAL 45",     464250 },
    { "PAL 46",     471250 },
    { "PAL 47",     478250 },
    { "PAL 48",     485250 },
    { "PAL 49",     492250 },
    { "PAL 50",     499250 },
    { "PAL 51",     506250 },
    { "PAL 52",     513250 },
    { "PAL 53",     520250 },
    { "PAL 54",     527250 },
    { "PAL 55",     534250 },
};


/* europe west and east              */

/* CCIR frequencies */

#define FREQ_CCIR_I_III   \
    { "CCIR I/III E2",      48250 }, \
    { "CCIR I/III E3",      55250 }, \
    { "CCIR I/III E4",      62250 }, \
    { "CCIR I/III S01",     69250 }, \
    { "CCIR I/III S02",     76250 }, \
    { "CCIR I/III S03",     83250 }, \
    { "CCIR I/III E5",     175250 }, \
    { "CCIR I/III E6",     182250 }, \
    { "CCIR I/III E7",     189250 }, \
    { "CCIR I/III E8",     196250 }, \
    { "CCIR I/III E9",     203250 }, \
    { "CCIR I/III E10",    210250 }, \
    { "CCIR I/III E11",    217250 }, \
    { "CCIR I/III E12",    224250 }

#define FREQ_CCIR_SL_SH \
    { "CCIR SL/SH SE1",    105250 }, \
    { "CCIR SL/SH SE2",    112250 }, \
    { "CCIR SL/SH SE3",    119250 }, \
    { "CCIR SL/SH SE4",    126250 }, \
    { "CCIR SL/SH SE5",    133250 }, \
    { "CCIR SL/SH SE6",    140250 }, \
    { "CCIR SL/SH SE7",    147250 }, \
    { "CCIR SL/SH SE8",    154250 }, \
    { "CCIR SL/SH SE9",    161250 }, \
    { "CCIR SL/SH SE10",   168250 }, \
    { "CCIR SL/SH SE11",   231250 }, \
    { "CCIR SL/SH SE12",   238250 }, \
    { "CCIR SL/SH SE13",   245250 }, \
    { "CCIR SL/SH SE14",   252250 }, \
    { "CCIR SL/SH SE15",   259250 }, \
    { "CCIR SL/SH SE16",   266250 }, \
    { "CCIR SL/SH SE17",   273250 }, \
    { "CCIR SL/SH SE18",   280250 }, \
    { "CCIR SL/SH SE19",   287250 }, \
    { "CCIR SL/SH SE20",   294250 }

#define FREQ_CCIR_H \
    { "CCIR H S21",    303250 }, \
    { "CCIR H S22",    311250 }, \
    { "CCIR H S23",    319250 }, \
    { "CCIR H S24",    327250 }, \
    { "CCIR H S25",    335250 }, \
    { "CCIR H S26",    343250 }, \
    { "CCIR H S27",    351250 }, \
    { "CCIR H S28",    359250 }, \
    { "CCIR H S29",    367250 }, \
    { "CCIR H S30",    375250 }, \
    { "CCIR H S31",    383250 }, \
    { "CCIR H S32",    391250 }, \
    { "CCIR H S33",    399250 }, \
    { "CCIR H S34",    407250 }, \
    { "CCIR H S35",    415250 }, \
    { "CCIR H S36",    423250 }, \
    { "CCIR H S37",    431250 }, \
    { "CCIR H S38",    439250 }, \
    { "CCIR H S39",    447250 }, \
    { "CCIR H S40",    455250 }, \
    { "CCIR H S41",    463250 }
 
/* OIRT frequencies (europe east) */
#define FREQ_OIRT_I_III \
    { "OIRT I/III R1",      49750 }, \
    { "OIRT I/III R2",      59250 }, \
    { "OIRT I/III R3",      77250 }, \
    { "OIRT I/III R4",      85250 }, \
    { "OIRT I/III R5",      93250 }, \
    { "OIRT I/III R6",     175250 }, \
    { "OIRT I/III R7",     183250 }, \
    { "OIRT I/III R8",     191250 }, \
    { "OIRT I/III R9",     199250 }, \
    { "OIRT I/III R10",    207250 }, \
    { "OIRT I/III R11",    215250 }, \
    { "OIRT I/III R12",    223250 }

#define FREQ_OIRT_SL_SH \
    { "OIRT SL/SH SR1",    111250 }, \
    { "OIRT SL/SH SR2",    119250 }, \
    { "OIRT SL/SH SR3",    127250 }, \
    { "OIRT SL/SH SR4",    135250 }, \
    { "OIRT SL/SH SR5",    143250 }, \
    { "OIRT SL/SH SR6",    151250 }, \
    { "OIRT SL/SH SR7",    159250 }, \
    { "OIRT SL/SH SR8",    167250 }, \
    { "OIRT SL/SH SR11",   231250 }, \
    { "OIRT SL/SH SR12",   239250 }, \
    { "OIRT SL/SH SR13",   247250 }, \
    { "OIRT SL/SH SR14",   255250 }, \
    { "OIRT SL/SH SR15",   263250 }, \
    { "OIRT SL/SH SR16",   271250 }, \
    { "OIRT SL/SH SR17",   279250 }, \
    { "OIRT SL/SH SR18",   287250 }, \
    { "OIRT SL/SH SR19",   295250 }

/* uhf frequencies, east and west */
#define FREQ_UHF \
    { "UHF 21",     471250 }, \
    { "UHF 22",     479250 }, \
    { "UHF 23",     487250 }, \
    { "UHF 24",     495250 }, \
    { "UHF 25",     503250 }, \
    { "UHF 26",     511250 }, \
    { "UHF 27",     519250 }, \
    { "UHF 28",     527250 }, \
    { "UHF 29",     535250 }, \
    { "UHF 30",     543250 }, \
    { "UHF 31",     551250 }, \
    { "UHF 32",     559250 }, \
    { "UHF 33",     567250 }, \
    { "UHF 34",     575250 }, \
    { "UHF 35",     583250 }, \
    { "UHF 36",     591250 }, \
    { "UHF 37",     599250 }, \
    { "UHF 38",     607250 }, \
    { "UHF 39",     615250 }, \
    { "UHF 40",     623250 }, \
    { "UHF 41",     631250 }, \
    { "UHF 42",     639250 }, \
    { "UHF 43",     647250 }, \
    { "UHF 44",     655250 }, \
    { "UHF 45",     663250 }, \
    { "UHF 46",     671250 }, \
    { "UHF 47",     679250 }, \
    { "UHF 48",     687250 }, \
    { "UHF 49",     695250 }, \
    { "UHF 50",     703250 }, \
    { "UHF 51",     711250 }, \
    { "UHF 52",     719250 }, \
    { "UHF 53",     727250 }, \
    { "UHF 54",     735250 }, \
    { "UHF 55",     743250 }, \
    { "UHF 56",     751250 }, \
    { "UHF 57",     759250 }, \
    { "UHF 58",     767250 }, \
    { "UHF 59",     775250 }, \
    { "UHF 60",     783250 }, \
    { "UHF 61",     791250 }, \
    { "UHF 62",     799250 }, \
    { "UHF 63",     807250 }, \
    { "UHF 64",     815250 }, \
    { "UHF 65",     823250 }, \
    { "UHF 66",     831250 }, \
    { "UHF 67",     839250 }, \
    { "UHF 68",     847250 }, \
    { "UHF 69",     855250 }
    
static struct cFreqlist europe_west[] = {
     FREQ_CCIR_I_III,
     FREQ_CCIR_SL_SH,
     FREQ_CCIR_H,
     FREQ_UHF
};
    
static struct cFreqlist europe_east[] = {
     FREQ_OIRT_I_III,
     FREQ_OIRT_SL_SH,
     FREQ_CCIR_I_III,
     FREQ_CCIR_SL_SH,
     FREQ_CCIR_H,
     FREQ_UHF
};

static struct cFreqlist pal_italy[] = {
    { "PAL A",       53750 },
    { "PAL B",       62250 },
    { "PAL C",       82250 },
    { "PAL D",      175250 },
    { "PAL E",      183750 },
    { "PAL F",      192250 },
    { "PAL G",      201250 },
    { "PAL H",      210250 },
    { "PAL H1",     217250 },
    { "PAL H2",     224250 },
    FREQ_UHF
};
    
static struct cFreqlist pal_ireland[] = {
    { "PAL A0",      45750 },
    { "PAL A1",      48000 },
    { "PAL A2",      53750 },
    { "PAL A3",      56000 },
    { "PAL A4",      61750 },
    { "PAL A5",      64000 },
    { "PAL A6",     175250 },
    { "PAL A7",     176000 },
    { "PAL A8",     183250 },
    { "PAL A9",     184000 },
    { "PAL A10",    191250 },
    { "PAL A11",    192000 },
    { "PAL A12",    199250 },
    { "PAL A13",    200000 },
    { "PAL A14",    207250 },
    { "PAL A15",    208000 },
    { "PAL A16",    215250 },
    { "PAL A17",    216000 },
    { "PAL A18",    224000 },
    { "PAL A19",    232000 },
    { "PAL A20",    248000 },
    { "PAL A21",    256000 },
    { "PAL A22",    264000 },
    { "PAL A23",    272000 },
    { "PAL A24",    280000 },
    { "PAL A25",    288000 },
    { "PAL A26",    296000 },
    { "PAL A27",    304000 },
    { "PAL A28",    312000 },
    { "PAL A29",    320000 },
    { "PAL A30",    344000 },
    { "PAL A31",    352000 },
    { "PAL A32",    408000 },
    { "PAL A33",    416000 },
    { "PAL A34",    448000 },
    { "PAL A35",    480000 },
    { "PAL A36",    520000 },
    FREQ_UHF,
};

static struct cFreqlist secam_france[] = {
    { "SECAM K01",     47750 },
    { "SECAM K02",     55750 },
    { "SECAM K03",     60500 },
    { "SECAM K04",     63750 },
    { "SECAM K05",    176000 },
    { "SECAM K06",    184000 },
    { "SECAM K07",    192000 },
    { "SECAM K08",    200000 },
    { "SECAM K09",    208000 },
    { "SECAM K10",    216000 },
    { "SECAM KB",     116750 },
    { "SECAM KC",     128750 },
    { "SECAM KD",     140750 },
    { "SECAM KE",     159750 },
    { "SECAM KF",     164750 },
    { "SECAM KG",     176750 },
    { "SECAM KH",     188750 },
    { "SECAM KI",     200750 },
    { "SECAM KJ",     212750 },
    { "SECAM KK",     224750 },
    { "SECAM KL",     236750 },
    { "SECAM KM",     248750 },
    { "SECAM KN",     260750 },
    { "SECAM KO",     272750 },
    { "SECAM KP",     284750 },
    { "SECAM KQ",     296750 },
    { "SECAM H01",    303250 },
    { "SECAM H02",    311250 },
    { "SECAM H03",    319250 },
    { "SECAM H04",    327250 },
    { "SECAM H05",    335250 },
    { "SECAM H06",    343250 },
    { "SECAM H07",    351250 },
    { "SECAM H08",    359250 },
    { "SECAM H09",    367250 },
    { "SECAM H10",    375250 },
    { "SECAM H11",    383250 },
    { "SECAM H12",    391250 },
    { "SECAM H13",    399250 },
    { "SECAM H14",    407250 },
    { "SECAM H15",    415250 },
    { "SECAM H16",    423250 },
    { "SECAM H17",    431250 },
    { "SECAM H18",    439250 },
    { "SECAM H19",    447250 },
    FREQ_UHF,
};


static struct cFreqlist pal_newzealand[] = {
    { "PAL 1",       45250 }, 
    { "PAL 2",       55250 }, 
    { "PAL 3",       62250 },
    { "PAL 4",      175250 },
    { "PAL 5",      182250 },
    { "PAL 6",      189250 },
    { "PAL 7",      196250 },
    { "PAL 8",      203250 },
    { "PAL 9",      210250 },
    { "PAL 10",     217250 },
    { "PAL 11",     224250 },
    FREQ_UHF,
};

/* China PAL broadcast */
static struct cFreqlist pal_bcast_cn[] = {
    { "PAL 1",       49750 },
    { "PAL 2",       57750 },
    { "PAL 3",       65750 },
    { "PAL 4",       77250 },
    { "PAL 5",       85250 },
    { "PAL 6",      112250 },
    { "PAL 7",      120250 },
    { "PAL 8",      128250 },
    { "PAL 9",      136250 },
    { "PAL 10",     144250 },
    { "PAL 11",     152250 },
    { "PAL 12",     160250 },
    { "PAL 13",     168250 },
    { "PAL 14",     176250 },
    { "PAL 15",     184250 },
    { "PAL 16",     192250 },
    { "PAL 17",     200250 },
    { "PAL 18",     208250 },
    { "PAL 19",     216250 },
    { "PAL 20",     224250 },
    { "PAL 21",     232250 },
    { "PAL 22",     240250 },
    { "PAL 23",     248250 },
    { "PAL 24",     256250 },
    { "PAL 25",     264250 },
    { "PAL 26",     272250 },
    { "PAL 27",     280250 },
    { "PAL 28",     288250 },
    { "PAL 29",     296250 },
    { "PAL 30",     304250 },
    { "PAL 31",     312250 },
    { "PAL 32",     320250 },
    { "PAL 33",     328250 },
    { "PAL 34",     336250 },
    { "PAL 35",     344250 },
    { "PAL 36",     352250 },
    { "PAL 37",     360250 },
    { "PAL 38",     368250 },
    { "PAL 39",     376250 },
    { "PAL 40",     384250 },
    { "PAL 41",     392250 },
    { "PAL 42",     400250 },
    { "PAL 43",     408250 },
    { "PAL 44",     416250 },
    { "PAL 45",     424250 },
    { "PAL 46",     432250 },
    { "PAL 47",     440250 },
    { "PAL 48",     448250 },
    { "PAL 49",     456250 },
    { "PAL 50",     463250 },
    { "PAL 51",     471250 },
    { "PAL 52",     479250 },
    { "PAL 53",     487250 },
    { "PAL 54",     495250 },
    { "PAL 55",     503250 },
    { "PAL 56",     511250 },
    { "PAL 57",     519250 },
    { "PAL 58",     527250 },
    { "PAL 59",     535250 },
    { "PAL 60",     543250 },
    { "PAL 61",     551250 },
    { "PAL 62",     559250 },
    { "PAL 63",     607250 },
    { "PAL 64",     615250 },
    { "PAL 65",     623250 },
    { "PAL 66",     631250 },
    { "PAL 67",     639250 },
    { "PAL 68",     647250 },
    { "PAL 69",     655250 },
    { "PAL 70",     663250 },
    { "PAL 71",     671250 },
    { "PAL 72",     679250 },
    { "PAL 73",     687250 },
    { "PAL 74",     695250 },
    { "PAL 75",     703250 },
    { "PAL 76",     711250 },
    { "PAL 77",     719250 },
    { "PAL 78",     727250 },
    { "PAL 79",     735250 },
    { "PAL 80",     743250 },
    { "PAL 81",     751250 },
    { "PAL 82",     759250 },
    { "PAL 83",     767250 },
    { "PAL 84",     775250 },
    { "PAL 85",     783250 },
    { "PAL 86",     791250 },
    { "PAL 87",     799250 },
    { "PAL 88",     807250 },
    { "PAL 89",     815250 },
    { "PAL 90",     823250 },
    { "PAL 91",     831250 },
    { "PAL 92",     839250 },
    { "PAL 93",     847250 },
    { "PAL 94",     855250 },
};

/* South Africa PAL Broadcast */

static struct cFreqlist pal_bcast_za[] ={
    { "PAL 4",      175250 },
    { "PAL 5",      183250 },
    { "PAL 6",      191250 },
    { "PAL 7",      199250 },
    { "PAL 8",      207250 },
    { "PAL 9",      215250 },
    { "PAL 10",     223250 },
    { "PAL 11",     231250 },
    { "PAL 12",     239250 },
    { "PAL 13",     247250 },
    FREQ_UHF
};

static struct cFreqlist argentina[] = {
    { "PAL 001",     56250 },
    { "PAL 002",     62250 },
    { "PAL 003",     68250 },
    { "PAL 004",     78250 },
    { "PAL 005",     84250 },
    { "PAL 006",    176250 },
    { "PAL 007",    182250 },
    { "PAL 008",    188250 },
    { "PAL 009",    194250 },
    { "PAL 010",    200250 },
    { "PAL 011",    206250 },
    { "PAL 012",    212250 },
    { "PAL 013",    122250 },
    { "PAL 014",    128250 },
    { "PAL 015",    134250 },
    { "PAL 016",    140250 },
    { "PAL 017",    146250 },
    { "PAL 018",    152250 },
    { "PAL 019",    158250 },
    { "PAL 020",    164250 },
    { "PAL 021",    170250 },
    { "PAL 022",    218250 },
    { "PAL 023",    224250 },
    { "PAL 024",    230250 },
    { "PAL 025",    236250 },
    { "PAL 026",    242250 },
    { "PAL 027",    248250 },
    { "PAL 028",    254250 },
    { "PAL 029",    260250 },
    { "PAL 030",    266250 },
    { "PAL 031",    272250 },
    { "PAL 032",    278250 },
    { "PAL 033",    284250 },
    { "PAL 034",    290250 },
    { "PAL 035",    296250 },
    { "PAL 036",    302250 },
    { "PAL 037",    308250 },
    { "PAL 038",    314250 },
    { "PAL 039",    320250 },
    { "PAL 040",    326250 },
    { "PAL 041",    332250 },
    { "PAL 042",    338250 },
    { "PAL 043",    344250 },
    { "PAL 044",    350250 },
    { "PAL 045",    356250 },
    { "PAL 046",    362250 },
    { "PAL 047",    368250 },
    { "PAL 048",    374250 },
    { "PAL 049",    380250 },
    { "PAL 050",    386250 },
    { "PAL 051",    392250 },
    { "PAL 052",    398250 },
    { "PAL 053",    404250 },
    { "PAL 054",    410250 },
    { "PAL 055",    416250 },
    { "PAL 056",    422250 },
    { "PAL 057",    428250 },
    { "PAL 058",    434250 },
    { "PAL 059",    440250 },
    { "PAL 060",    446250 },
    { "PAL 061",    452250 },
    { "PAL 062",    458250 },
    { "PAL 063",    464250 },
    { "PAL 064",    470250 },
    { "PAL 065",    476250 },
    { "PAL 066",    482250 },
    { "PAL 067",    488250 },
    { "PAL 068",    494250 },
    { "PAL 069",    500250 },
    { "PAL 070",    506250 },
    { "PAL 071",    512250 },
    { "PAL 072",    518250 },
    { "PAL 073",    524250 },
    { "PAL 074",    530250 },
    { "PAL 075",    536250 },
    { "PAL 076",    542250 },
    { "PAL 077",    548250 },
    { "PAL 078",    554250 },
    { "PAL 079",    560250 },
    { "PAL 080",    566250 },
    { "PAL 081",    572250 },
    { "PAL 082",    578250 },
    { "PAL 083",    584250 },
    { "PAL 084",    590250 },
    { "PAL 085",    596250 },
    { "PAL 086",    602250 },
    { "PAL 087",    608250 },
    { "PAL 088",    614250 },
    { "PAL 089",    620250 },
    { "PAL 090",    626250 },
    { "PAL 091",    632250 },
    { "PAL 092",    638250 },
    { "PAL 093",    644250 },
};


const struct cFreqlists freqlists[] = {
    { "ntsc",            ntsc,                FREQ_COUNT(ntsc)                },
    { "ntsc-japan",      ntsc_japan,          FREQ_COUNT(ntsc_japan)          },  
    { "europe-west",     europe_west,         FREQ_COUNT(europe_west)         },
    { "europe-east",     europe_east,         FREQ_COUNT(europe_east)         },
    { "italy",           pal_italy,           FREQ_COUNT(pal_italy)           },
    { "newzealand",      pal_newzealand,      FREQ_COUNT(pal_newzealand)      },
    { "australia",       pal_australia,       FREQ_COUNT(pal_australia)       },
    { "ireland",         pal_ireland,         FREQ_COUNT(pal_ireland)         },
    { "france",          secam_france,        FREQ_COUNT(secam_france)        },
    { "china-bcast",     pal_bcast_cn,        FREQ_COUNT(pal_bcast_cn)        },
    { "southafrica",     pal_bcast_za,        FREQ_COUNT(pal_bcast_za)        },
    { "argentina",       argentina,           FREQ_COUNT(argentina)           },
    { "australia-optus", pal_australia_optus, FREQ_COUNT(pal_australia_optus) },
    { NULL,              NULL,                0                               } /* EOF */
};

#define    FREQLIST_NTSC                 0
#define    FREQLIST_NTSC_JAPAN           1
#define    FREQLIST_PAL_EUROPE_WEST      2
#define    FREQLIST_PAL_EUROPE_EAST      3
#define    FREQLIST_PAL_ITALY            4
#define    FREQLIST_PAL_NEWZEALAND       5
#define    FREQLIST_PAL_AUSTRALIA        6
#define    FREQLIST_PAL_IRELAND          7
#define    FREQLIST_SECAM_FRANCE         8
#define    FREQLIST_PAL_CHINA            9
#define    FREQLIST_PAL_SOUTHAFRIKA     10
#define    FREQLIST_PAL_ARGENTINIA      11
#define    FREQLIST_PAL_AUSTRALIA_OPUS  12


/* this list has to be checked later one, at the moment
 i dont have any ideas how to get the information needed
 for channel scan.
 So the *only* garanteed working list is germany which
 definitely uses europe_west.

 IF ANYBODY KNOWN A LIST WHICH COUNTRY USES WHICH
 FREQUENCY, PLEASE SEND IT TO ME. 

 -wirbel- 20061015
*/

const struct cCountry CountryProperties[] = {
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Afghanistan              */       
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Albania                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Algeria                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Angola                   */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Antigua                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Arab Emirates            */      
    { FREQLIST_PAL_ARGENTINIA  , V4L2_STD_PAL   , 0, 0 },       /*Argentinia               */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Armenia                  */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Aruba                    */      
    { FREQLIST_PAL_AUSTRALIA   , V4L2_STD_PAL   , 0, 0 },       /*Australia                */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Austria                  */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Azerbaijan               */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Bahamas                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Bahrain                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Bangladesh               */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Barbados                 */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Belarus                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Belgium                  */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Belize                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Benin                    */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Bermuda                  */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Bolivia                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Bosnia/Herzegovinia      */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Botswana                 */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Brazil                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Bulgaria                 */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Burkina Faso             */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Burundi                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Brunei Darussalam        */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Burma                    */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Cape Verde               */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Cambodia                 */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Cameroon                 */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Canada                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Central African          */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Chad                     */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Chile                    */      
    { FREQLIST_PAL_CHINA       , V4L2_STD_PAL   , 0, 0 },       /*China                    */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Colombia                 */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Congo                    */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Costa Rica               */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Croatia                  */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Cuba                     */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Curacao                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Cyprus                   */      
    { FREQLIST_PAL_EUROPE_EAST , V4L2_STD_PAL   , 0, 0 },       /*Czech Republic           */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Denmark                  */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Djibouti                 */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Dominican Republic       */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Ecuador                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Egypt                    */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Equatorial Guinea        */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*El Salvador              */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Estonia                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Ethiopia                 */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Finland                  */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*France                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Gabon                    */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Gambia                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Georgia                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Germany                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Ghana                    */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Gibraltar                */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Greece                   */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Greenland                */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Guatemala                */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Guinea-Bissau            */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Honduras                 */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Hong Kong                */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Hungary                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Iceland                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*India                    */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Indonesia                */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Iran                     */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Iraq                     */      
    { FREQLIST_PAL_IRELAND     , V4L2_STD_PAL   , 0, 0 },       /*Ireland                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Israel                   */      
    { FREQLIST_PAL_ITALY       , V4L2_STD_PAL   , 0, 0 },       /*Italy                    */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Jamaica                  */      
    { FREQLIST_NTSC_JAPAN      , V4L2_STD_NTSC  , 0, 0 },       /*Japan                    */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Jordan                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Kazakhstan               */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Kenya                    */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Korea (South)            */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Kuwait                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Lebanon                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Lesotho                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Liberia                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Libya                    */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Lithuania                */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Luxembourg               */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Madagascar               */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Malawi                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Mali                     */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Malaysa                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Maldives                 */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Malta                    */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Mauritania               */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Mauritus                 */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Mexico                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Moldovia                 */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Monaco                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Mongolia                 */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Montserrat               */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Morocco                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Mozambique               */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Myanmar                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Nambia                   */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Nepal                    */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Netherlands              */      
    { FREQLIST_PAL_NEWZEALAND  , V4L2_STD_PAL   , 0, 0 },       /*New Zealand              */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Nicaragua                */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Nigeria                  */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Niger                    */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*North Korea              */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Norway                   */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Oman                     */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Pakistan                 */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Panama                   */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Papua New Guinea         */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Paraguay                 */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Peru                     */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Philippines              */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Poland                   */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Portugal                 */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Puerto Rico              */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Qatar                    */      
    { FREQLIST_PAL_EUROPE_EAST , V4L2_STD_PAL   , 0, 0 },       /*Romania                  */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Russia                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Rwanda                   */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Samoa                    */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Sao Tome/Principe        */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Saudi Arabia             */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Saudi Arabia             */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Senegal                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Seychelles               */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Sierra Leone             */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Singapore                */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Slovak Republic          */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Slovenia                 */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Somalia                  */      
    { FREQLIST_PAL_SOUTHAFRIKA , V4L2_STD_PAL   , 0, 0 },       /*South Africa             */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Spain                    */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Sri Lanka                */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*St Christopher/Nevis     */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Sudan                    */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Suriname                 */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Swaziland                */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Sweden                   */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Switzerland              */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Syria                    */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Taiwan                   */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Tanzania                 */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Thailand                 */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Togo                     */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Trinidad/Tobago          */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Tunisia                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Turkey                   */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Uganda                   */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Ukraine                  */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*United Kingdom           */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*United States            */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Uruguay                  */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Venezuela                */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Vietnam                  */      
    { FREQLIST_NTSC            , V4L2_STD_NTSC  , 0, 0 },       /*Virgin Islands           */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Zaire                    */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Zambia                   */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Zanzibar                 */      
    { FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM , 0, 0 },       /*Zazakhstan               */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Zimbabwe                 */      
    { FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   , 0, 0 },       /*Yemen                    */      
    { 0, 0, 0, 0 }                          /* EOF */           /*NULL                     */       
};


/* has to be EXACTLY the same order like countrylist[]
   check this twice.
 */

const char * CountryNames[] = {        
    "Afghanistan"             ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Albania"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Algeria"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Angola"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Antigua"                 ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Arab Emirates"           ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Argentinia"              ,                          /* FREQLIST_PAL_ARGENTINIA  , V4L2_STD_PAL   */
    "Armenia"                 ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Aruba"                   ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Australia"               ,                          /* FREQLIST_PAL_AUSTRALIA   , V4L2_STD_PAL   */
    "Austria"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Azerbaijan"              ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Bahamas"                 ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Bahrain"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Bangladesh"              ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Barbados"                ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Belarus"                 ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Belgium"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Belize"                  ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Benin"                   ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Bermuda"                 ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Bolivia"                 ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Bosnia/Herzegovinia"     ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Botswana"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Brazil"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Bulgaria"                ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Burkina Faso"            ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Burundi"                 ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Brunei Darussalam"       ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Burma"                   ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Cape Verde"              ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Cambodia"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Cameroon"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Canada"                  ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Central African"         ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Chad"                    ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Chile"                   ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "China"                   ,                          /* FREQLIST_PAL_CHINA       , V4L2_STD_PAL   */
    "Colombia"                ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Congo"                   ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Costa Rica"              ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Croatia"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Cuba"                    ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Curacao"                 ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Cyprus"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Czech Republic"          ,                          /* FREQLIST_PAL_EUROPE_EAST , V4L2_STD_PAL   */
    "Denmark"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Djibouti"                ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Dominican Republic"      ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Ecuador"                 ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Egypt"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Equatorial Guinea"       ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "El Salvador"             ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Estonia"                 ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Ethiopia"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Finland"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "France"                  ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Gabon"                   ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Gambia"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Georgia"                 ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Germany"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Ghana"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Gibraltar"               ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Greece"                  ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Greenland"               ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Guatemala"               ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Guinea-Bissau"           ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Honduras"                ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Hong Kong"               ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Hungary"                 ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Iceland"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "India"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Indonesia"               ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Iran"                    ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Iraq"                    ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Ireland"                 ,                          /* FREQLIST_PAL_IRELAND     , V4L2_STD_PAL   */
    "Israel"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Italy"                   ,                          /* FREQLIST_PAL_ITALY       , V4L2_STD_PAL   */
    "Jamaica"                 ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Japan"                   ,                          /* FREQLIST_NTSC_JAPAN      , V4L2_STD_NTSC  */
    "Jordan"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Kazakhstan"              ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Kenya"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Korea (South)"           ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Kuwait"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Lebanon"                 ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Lesotho"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Liberia"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Libya"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Lithuania"               ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Luxembourg"              ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Madagascar"              ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Malawi"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Mali"                    ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Malaysa"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Maldives"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Malta"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Mauritania"              ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Mauritus"                ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Mexico"                  ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Moldovia"                ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Monaco"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Mongolia"                ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Montserrat"              ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Morocco"                 ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Mozambique"              ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Myanmar"                 ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Nambia"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Nepal"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Netherlands"             ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "New Zealand"             ,                          /* FREQLIST_PAL_NEWZEALAND  , V4L2_STD_PAL   */
    "Nicaragua"               ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Nigeria"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Niger"                   ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "North Korea"             ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Norway"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Oman"                    ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Pakistan"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Panama"                  ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Papua New Guinea"        ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Paraguay"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Peru"                    ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Philippines"             ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Poland"                  ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Portugal"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Puerto Rico"             ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Qatar"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Romania"                 ,                          /* FREQLIST_PAL_EUROPE_EAST , V4L2_STD_PAL   */
    "Russia"                  ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Rwanda"                  ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Samoa"                   ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Sao Tome/Principe"       ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Saudi Arabia"            ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Saudi Arabia"            ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Senegal"                 ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Seychelles"              ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Sierra Leone"            ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Singapore"               ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Slovak Republic"         ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Slovenia"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Somalia"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "South Africa"            ,                          /* FREQLIST_PAL_SOUTHAFRIKA , V4L2_STD_PAL   */
    "Spain"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Sri Lanka"               ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "St Christopher/Nevis"    ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Sudan"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Suriname"                ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Swaziland"               ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Sweden"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Switzerland"             ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Syria"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Taiwan"                  ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Tanzania"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Thailand"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Togo"                    ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Trinidad/Tobago"         ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Tunisia"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Turkey"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Uganda"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Ukraine"                 ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "United Kingdom"          ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "United States"           ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Uruguay"                 ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Venezuela"               ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Vietnam"                 ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Virgin Islands"          ,                          /* FREQLIST_NTSC            , V4L2_STD_NTSC  */
    "Zaire"                   ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Zambia"                  ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Zanzibar"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Zazakhstan"              ,                          /* FREQLIST_SECAM_FRANCE    , V4L2_STD_SECAM */
    "Zimbabwe"                ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    "Yemen"                   ,                          /* FREQLIST_PAL_EUROPE_WEST , V4L2_STD_PAL   */
    NULL                                                 /* NULL                     , 0 }  EOF       */
};



static struct cFreqlist DVB_T_PAL[] = {
    { "DVB-T 05",    177500 },
    { "DVB-T 06",    184500 },
    { "DVB-T 07",    191500 },
    { "DVB-T 08",    198500 },
    { "DVB-T 09",    205500 },
    { "DVB-T 10",    212500 },
    { "DVB-T 11",    219500 },
    { "DVB-T 12",    226500 },
    { "DVB-T 21",    474000 },
    { "DVB-T 22",    482000 },
    { "DVB-T 23",    490000 },
    { "DVB-T 24",    498000 },
    { "DVB-T 25",    506000 },
    { "DVB-T 26",    514000 },
    { "DVB-T 27",    522000 },
    { "DVB-T 28",    530000 },
    { "DVB-T 29",    538000 },
    { "DVB-T 30",    546000 },
    { "DVB-T 31",    554000 },
    { "DVB-T 32",    562000 },
    { "DVB-T 33",    570000 },
    { "DVB-T 34",    578000 },
    { "DVB-T 35",    586000 },
    { "DVB-T 36",    594000 },
    { "DVB-T 37",    602000 },
    { "DVB-T 38",    610000 },
    { "DVB-T 39",    618000 },
    { "DVB-T 40",    626000 },
    { "DVB-T 41",    634000 },
    { "DVB-T 42",    642000 },
    { "DVB-T 43",    650000 },
    { "DVB-T 44",    658000 },
    { "DVB-T 45",    666000 },
    { "DVB-T 46",    674000 },
    { "DVB-T 47",    682000 },
    { "DVB-T 48",    690000 },
    { "DVB-T 49",    698000 },
    { "DVB-T 50",    706000 },
    { "DVB-T 51",    714000 },
    { "DVB-T 52",    722000 },
    { "DVB-T 53",    730000 },
    { "DVB-T 54",    738000 },
    { "DVB-T 55",    746000 },
    { "DVB-T 56",    754000 },
    { "DVB-T 57",    762000 },
    { "DVB-T 58",    770000 },
    { "DVB-T 59",    778000 },
    { "DVB-T 60",    786000 },
    { "DVB-T 61",    794000 },
    { "DVB-T 62",    802000 },
    { "DVB-T 63",    810000 },
    { "DVB-T 64",    818000 },
    { "DVB-T 65",    826000 },
    { "DVB-T 66",    834000 },
    { "DVB-T 67",    842000 },
    { "DVB-T 68",    850000 },
    { "DVB-T 69",    858000 },
};

static struct cFreqlist DVB_T_NTSC[] = {
};

static struct cFreqlist DVB_T_SECAM[] = {
};


const struct cFreqlists freqlistsDVBT[] = {
    { "DVB-T PAL",       DVB_T_PAL,           FREQ_COUNT(DVB_T_PAL)           },
    { "DVB-T NTSC",      DVB_T_NTSC,          FREQ_COUNT(DVB_T_NTSC)          },
    { "DVB-T SECAM",     DVB_T_SECAM,         FREQ_COUNT(DVB_T_SECAM)         },
    { NULL,              NULL,                0                               } /* EOF */
};

#define    FREQLIST_DVBT_PAL             0
#define    FREQLIST_DVBT_NTSC            1
#define    FREQLIST_DVBT_SECAM           2
#define    FREQLIST_DVBT_OTHER           3

#define    FREQ_OFFSET_UK                167
#define    FREQ_OFFSET_FR                167
#define    FREQ_OFFSET_SP                167


/* not yet defined, this is _preliminary_!! Valid for europe_west only! */

const struct cCountry CountryPropertiesDVBT[] = {
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Afghanistan              */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Albania                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Algeria                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Angola                   */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Antigua                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Arab Emirates            */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Argentinia               */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Armenia                  */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Aruba                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Australia                */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Austria                  */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Azerbaijan               */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Bahamas                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Bahrain                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Bangladesh               */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Barbados                 */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Belarus                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Belgium                  */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Belize                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Benin                    */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Bermuda                  */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Bolivia                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Bosnia/Herzegovinia      */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Botswana                 */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Brazil                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Bulgaria                 */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Burkina Faso             */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Burundi                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Brunei Darussalam        */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Burma                    */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Cape Verde               */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Cambodia                 */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Cameroon                 */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Canada                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Central African          */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Chad                     */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Chile                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*China                    */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Colombia                 */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Congo                    */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Costa Rica               */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Croatia                  */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Cuba                     */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Curacao                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Cyprus                   */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Czech Republic           */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Denmark                  */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Djibouti                 */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Dominican Republic       */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Ecuador                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Egypt                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Equatorial Guinea        */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*El Salvador              */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Estonia                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Ethiopia                 */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Finland                  */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_UP  , FREQ_OFFSET_FR   },       /*France                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Gabon                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Gambia                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Georgia                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Germany                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Ghana                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Gibraltar                */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Greece                   */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Greenland                */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Guatemala                */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Guinea-Bissau            */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Honduras                 */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Hong Kong                */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Hungary                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Iceland                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*India                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Indonesia                */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Iran                     */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Iraq                     */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Ireland                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Israel                   */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Italy                    */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Jamaica                  */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Japan                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Jordan                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Kazakhstan               */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Kenya                    */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Korea (South)            */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Kuwait                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Lebanon                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Lesotho                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Liberia                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Libya                    */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Lithuania                */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Luxembourg               */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Madagascar               */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Malawi                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Mali                     */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Malaysa                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Maldives                 */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Malta                    */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Mauritania               */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Mauritus                 */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Mexico                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Moldovia                 */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Monaco                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Mongolia                 */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Montserrat               */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Morocco                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Mozambique               */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Myanmar                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Nambia                   */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Nepal                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Netherlands              */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*New Zealand              */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Nicaragua                */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Nigeria                  */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Niger                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*North Korea              */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Norway                   */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Oman                     */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Pakistan                 */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Panama                   */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Papua New Guinea         */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Paraguay                 */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Peru                     */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Philippines              */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Poland                   */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Portugal                 */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Puerto Rico              */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Qatar                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Romania                  */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Russia                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Rwanda                   */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Samoa                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Sao Tome/Principe        */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Saudi Arabia             */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Saudi Arabia             */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Senegal                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Seychelles               */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Sierra Leone             */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Singapore                */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Slovak Republic          */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Slovenia                 */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Somalia                  */ 
    { FREQLIST_DVBT_OTHER    , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*South Africa             */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_BOTH, FREQ_OFFSET_SP   },       /*Spain                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Sri Lanka                */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*St Christopher/Nevis     */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Sudan                    */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Suriname                 */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Swaziland                */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Sweden                   */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Switzerland              */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Syria                    */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Taiwan                   */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Tanzania                 */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Thailand                 */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Togo                     */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Trinidad/Tobago          */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Tunisia                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Turkey                   */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Uganda                   */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Ukraine                  */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_BOTH, FREQ_OFFSET_UK   },       /*United Kingdom           */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*United States            */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Uruguay                  */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Venezuela                */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Vietnam                  */ 
    { FREQLIST_DVBT_NTSC     , V4L2_STD_NTSC  , FREQ_OFFSET_OFF , 0                },       /*Virgin Islands           */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Zaire                    */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Zambia                   */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Zanzibar                 */ 
    { FREQLIST_DVBT_SECAM    , V4L2_STD_SECAM , FREQ_OFFSET_OFF , 0                },       /*Zazakhstan               */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Zimbabwe                 */ 
    { FREQLIST_DVBT_PAL      , V4L2_STD_PAL   , FREQ_OFFSET_OFF , 0                },       /*Yemen                    */ 
    { 0                      , 0              , 0               , 0 } /* EOF */  ,          /*NULL                     */       
};


/* dvb-c parts */

static struct cFreqlist DVB_C_PAL[] = {
    { "DVB-C 02",     50500 },
    { "DVB-C 03",     57500 },
    { "DVB-C 04",     64500 },
    { "DVB-C S01",    71500 },
    { "DVB-C S02",    78500 },
    { "DVB-C S03",    85500 },
    { "DVB-C SE1",   105000 },
    { "DVB-C SE1",   107500 },
    { "DVB-C SE2",   113000 },
    { "DVB-C SE2",   114500 },
    { "DVB-C SE3",   121000 },
    { "DVB-C SE3",   121500 },
    { "DVB-C SE4",   128500 },
    { "DVB-C SE4",   129000 },
    { "DVB-C SE5",   135500 },
    { "DVB-C SE5",   137000 },
    { "DVB-C SE6",   145000 },
    { "DVB-C SE6",   142500 },
    { "DVB-C SE7",   149500 },
    { "DVB-C xx",    153000 },
    { "DVB-C SE8",   156500 },
    { "DVB-C xx",    161000 },
    { "DVB-C SE9",   163500 },
    { "DVB-C SE10",  169000 },
    { "DVB-C SE10",  167500 },
    { "DVB-C 05",    177500 },
    { "DVB-C 06",    184500 },
    { "DVB-C 07",    191500 },
    { "DVB-C 08",    198500 },
    { "DVB-C 09",    205500 },
    { "DVB-C 10",    212500 },
    { "DVB-C 11",    219500 },
    { "DVB-C 12",    226500 },
    { "DVB-C SE11",  233500 },
    { "DVB-C Se12",  240500 },
    { "DVB-C SE13",  247500 },
    { "DVB-C SE14",  254500 },
    { "DVB-C SE15",  261500 },
    { "DVB-C SE16",  268500 },
    { "DVB-C SE17",  275500 },
    { "DVB-C SE18",  282500 },
    { "DVB-C SE19",  289500 },
    { "DVB-C SE20",  296500 },
    { "DVB-C S21",   306000 },
    { "DVB-C S22",   314000 },
    { "DVB-C S23",   322000 },
    { "DVB-C S24",   330000 },
    { "DVB-C S25",   338000 },
    { "DVB-C S26",   346000 },
    { "DVB-C S27",   354000 },
    { "DVB-C S28",   362000 },
    { "DVB-C S29",   370000 },
    { "DVB-C S30",   378000 },
    { "DVB-C S31",   386000 },
    { "DVB-C S32",   394000 },
    { "DVB-C S33",   402000 },
    { "DVB-C S34",   410000 },
    { "DVB-C S35",   418000 },
    { "DVB-C S36",   426000 },
    { "DVB-C S37",   434000 },
    { "DVB-C S38",   442000 },
    { "DVB-C S39",   450000 },
    { "DVB-C S40",   458000 },
    { "DVB-C S41",   466000 },
    { "DVB-C 21",    474000 },
    { "DVB-C 22",    482000 },
    { "DVB-C 23",    490000 },
    { "DVB-C 24",    498000 },
    { "DVB-C 25",    506000 },
    { "DVB-C 22",    514000 },
    { "DVB-C 27",    522000 },
    { "DVB-C 28",    530000 },
    { "DVB-C 29",    538000 },
    { "DVB-C 30",    546000 },
    { "DVB-C 31",    554000 },
    { "DVB-C 32",    562000 },
    { "DVB-C 33",    570000 },
    { "DVB-C 34",    578000 },
    { "DVB-C 35",    586000 },
    { "DVB-C 36",    594000 },
    { "DVB-C 37",    602000 },
    { "DVB-C 38",    610000 },
    { "DVB-C 39",    618000 },
    { "DVB-C 40",    626000 },
    { "DVB-C 41",    634000 },
    { "DVB-C 42",    642000 },
    { "DVB-C 43",    650000 },
    { "DVB-C 44",    658000 },
    { "DVB-C 45",    666000 },
    { "DVB-C 46",    674000 },
    { "DVB-C 47",    682000 },
    { "DVB-C 48",    690000 },
    { "DVB-C 49",    698000 },
    { "DVB-C 50",    706000 },
    { "DVB-C 51",    714000 },
    { "DVB-C 52",    722000 },
    { "DVB-C 53",    730000 },
    { "DVB-C 54",    738000 },
    { "DVB-C 55",    746000 },
    { "DVB-C 56",    754000 },
    { "DVB-C 57",    762000 },
    { "DVB-C 58",    770000 },
    { "DVB-C 59",    778000 },
    { "DVB-C 60",    786000 },
    { "DVB-C 61",    794000 },
    { "DVB-C 62",    802000 },
    { "DVB-C 63",    810000 },
    { "DVB-C 64",    818000 },
    { "DVB-C 65",    826000 },
    { "DVB-C 66",    834000 },
    { "DVB-C 67",    842000 },
    { "DVB-C 68",    850000 },
    { "DVB-C 69",    858000 },
};

                 
static struct cFreqlist DVB_C_NTSC[] = {
};                   
   
                  
static struct cFreqlist DVB_C_SECAM[] = {
};                   
                     
                     
const struct cFreqlists freqlistsDVBC[] = {
    { "DVB-T PAL",       DVB_C_PAL,           FREQ_COUNT(DVB_C_PAL)           },
    { "DVB-T NTSC",      DVB_C_NTSC,          FREQ_COUNT(DVB_C_NTSC)          },
    { "DVB-T SECAM",     DVB_C_SECAM,         FREQ_COUNT(DVB_C_SECAM)         },
    { NULL,              NULL,                0                               } /* EOF */
};                   
                     
#define    FREQLIST_DVBC_PAL             0
#define    FREQLIST_DVBC_NTSC            1
#define    FREQLIST_DVBC_SECAM           2
#define    FREQLIST_DVBC_OTHER           3
                     
                     
/* not yet defined, this is _preliminary_!! Valid for europe_west only! */
                     
const struct cCountry CountryPropertiesDVBC[] = {
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Afghanistan              */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Albania                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Algeria                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Angola                   */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Antigua                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Arab Emirates            */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Argentinia               */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Armenia                  */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Aruba                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Australia                */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Austria                  */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Azerbaijan               */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Bahamas                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Bahrain                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Bangladesh               */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Barbados                 */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Belarus                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Belgium                  */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Belize                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Benin                    */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Bermuda                  */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Bolivia                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Bosnia/Herzegovinia      */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Botswana                 */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Brazil                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Bulgaria                 */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Burkina Faso             */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Burundi                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Brunei Darussalam        */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Burma                    */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Cape Verde               */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Cambodia                 */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Cameroon                 */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Canada                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Central African          */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Chad                     */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Chile                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*China                    */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Colombia                 */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Congo                    */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Costa Rica               */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Croatia                  */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Cuba                     */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Curacao                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Cyprus                   */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Czech Republic           */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Denmark                  */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Djibouti                 */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Dominican Republic       */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Ecuador                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Egypt                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Equatorial Guinea        */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*El Salvador              */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Estonia                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Ethiopia                 */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Finland                  */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*France                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Gabon                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Gambia                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Georgia                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Germany                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Ghana                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Gibraltar                */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Greece                   */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Greenland                */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Guatemala                */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Guinea-Bissau            */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Honduras                 */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Hong Kong                */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Hungary                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Iceland                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*India                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Indonesia                */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Iran                     */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Iraq                     */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Ireland                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Israel                   */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Italy                    */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Jamaica                  */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Japan                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Jordan                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Kazakhstan               */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Kenya                    */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Korea (South)            */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Kuwait                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Lebanon                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Lesotho                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Liberia                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Libya                    */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Lithuania                */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Luxembourg               */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Madagascar               */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Malawi                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Mali                     */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Malaysa                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Maldives                 */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Malta                    */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Mauritania               */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Mauritus                 */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Mexico                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Moldovia                 */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Monaco                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Mongolia                 */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Montserrat               */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Morocco                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Mozambique               */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Myanmar                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Nambia                   */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Nepal                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Netherlands              */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*New Zealand              */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Nicaragua                */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Nigeria                  */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Niger                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*North Korea              */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Norway                   */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Oman                     */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Pakistan                 */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Panama                   */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Papua New Guinea         */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Paraguay                 */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Peru                     */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Philippines              */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Poland                   */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Portugal                 */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Puerto Rico              */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Qatar                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Romania                  */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Russia                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Rwanda                   */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Samoa                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Sao Tome/Principe        */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Saudi Arabia             */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Saudi Arabia             */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Senegal                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Seychelles               */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Sierra Leone             */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Singapore                */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Slovak Republic          */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Slovenia                 */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Somalia                  */ 
    { FREQLIST_DVBC_OTHER    , V4L2_STD_PAL   , 0, 0 },       /*South Africa             */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Spain                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Sri Lanka                */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*St Christopher/Nevis     */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Sudan                    */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Suriname                 */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Swaziland                */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Sweden                   */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Switzerland              */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Syria                    */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Taiwan                   */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Tanzania                 */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Thailand                 */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Togo                     */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Trinidad/Tobago          */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Tunisia                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Turkey                   */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Uganda                   */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Ukraine                  */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*United Kingdom           */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*United States            */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Uruguay                  */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Venezuela                */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Vietnam                  */ 
    { FREQLIST_DVBC_NTSC     , V4L2_STD_NTSC  , 0, 0 },       /*Virgin Islands           */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Zaire                    */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Zambia                   */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Zanzibar                 */ 
    { FREQLIST_DVBC_SECAM    , V4L2_STD_SECAM , 0, 0 },       /*Zazakhstan               */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Zimbabwe                 */ 
    { FREQLIST_DVBC_PAL      , V4L2_STD_PAL   , 0, 0 },       /*Yemen                    */ 
    { 0, 0, 0, 0 }                        /* EOF */           /*NULL                     */       
};
